@@ -23,6 +23,7 @@
 #include <gmodule.h>
 #include <gdk/gdk.h>
 #include <X11/Xlib.h>
+#include <gconf/gconf-client.h>
 #include "jawutil.h"
 #include "jawimpl.h"
 #include "jawtoplevel.h"
@@ -45,11 +46,6 @@ struct _DummyDispatch
 	GDestroyNotify destroy;
 };
 
-gboolean jaw_debug = FALSE;
-
-GMutex *atk_bridge_mutex = NULL;
-GCond *atk_bridge_cond = NULL;
-
 GMutex *key_dispatch_mutex = NULL;
 GCond *key_dispatch_cond = NULL;
 static gint key_dispatch_result = KEY_DISPATCH_NOT_DISPATCHED;
@@ -99,18 +95,25 @@ static void jaw_exit_func ()
 static gboolean
 jaw_load_atk_bridge (gpointer p)
 {
-	g_mutex_lock(atk_bridge_mutex);
-
 	if (!g_module_supported()) {
 		return NULL;
 	}
 
+	gboolean use_corba = gconf_client_get_bool(
+			gconf_client_get_default(),
+			"/desktop/gnome/interface/at-spi-corba",
+			NULL);
+
 	GModule *module;
-	module = g_module_open(ATK_BRIDGE_LIB_NAME, G_MODULE_BIND_LAZY);
+	if (use_corba)
+		module = g_module_open(ATK_BRIDGE_LIB_NAME_CORBA, G_MODULE_BIND_LAZY);
+	else
+		module = g_module_open(ATK_BRIDGE_LIB_NAME_DBUS, G_MODULE_BIND_LAZY);
+
 	if (!module) {
 		return NULL;
 	}
-
+	
 	GVoidFunc dl_init;
 	if (!g_module_symbol( module, "gnome_accessibility_module_init", (gpointer*)&dl_init)) {
 		g_module_close(module);
@@ -120,13 +123,6 @@ jaw_load_atk_bridge (gpointer p)
 	(dl_init)();
 	g_atexit( jaw_exit_func );
 
-	if (jaw_debug) {
-		printf("ATK Bridge has been loaded successfully\n");
-	}
-
-	g_cond_signal(atk_bridge_cond);
-	g_mutex_unlock(atk_bridge_mutex);
-
 	return FALSE;
 }
 
@@ -142,19 +138,10 @@ JNIEXPORT void JNICALL Java_org_GNOME_Accessibility_AtkWrapper_initNativeLibrary
 	// Hook up g_idle_dispatch
 	origin_g_idle_dispatch = g_idle_funcs.dispatch;
 	g_idle_funcs.dispatch = jaw_idle_dispatch;
-
-	const gchar* debug_env = g_getenv("JAW_DEBUG");
-	if (g_strcmp0(debug_env, "1") == 0) {
-		jaw_debug = TRUE;
-	}
 	
 	// Java app with GTK Look And Feel will load gail
 	// Set NO_GAIL to "1" to prevent gail from executing
 	g_setenv("NO_GAIL", "1", TRUE);
-	
-	// Disable ATK Bridge temporarily to aoid the loading
-	// of ATK Bridge by GTK look and feel
-	g_setenv("NO_AT_BRIDGE", "1", TRUE);
 
 	g_type_class_unref(g_type_class_ref(JAW_TYPE_UTIL));
 	g_type_class_unref(g_type_class_ref(JAW_TYPE_MISC));
@@ -168,35 +155,18 @@ JNIEXPORT void JNICALL Java_org_GNOME_Accessibility_AtkWrapper_initNativeLibrary
 
 	jaw_impl_init_mutex();
 
-	atk_bridge_mutex = g_mutex_new();
-	atk_bridge_cond = g_cond_new();
-
 	key_dispatch_mutex = g_mutex_new();
 	key_dispatch_cond = g_cond_new();
 
+	GMainLoop *main_loop = g_main_loop_new( NULL, FALSE );
+	
 	// Dummy idle function for jaw_idle_dispatch to get
 	// the address of gdk_threads_dispatch
 	gdk_threads_add_idle(jaw_dummy_idle_func, NULL);
-}
-
-JNIEXPORT void JNICALL Java_org_GNOME_Accessibility_AtkWrapper_loadAtkBridge(JNIEnv *jniEnv, jclass jClass) {
-	// Enable ATK Bridge so we can load it now
-	g_setenv("NO_AT_BRIDGE", "0", TRUE);
-
-	GMainLoop *main_loop = g_main_loop_new( NULL, FALSE );
-	
 	g_idle_add(jaw_load_atk_bridge, NULL);
 
-	// We need to wait for the completion of the loading of ATK Bridge
-	// in order to ensure event listeners in ATK Bridge are properly
-	// registered before any emission of AWT event.
-	g_mutex_lock(atk_bridge_mutex);
-
 	GThread *main_loop_thread = g_thread_create( jni_main_loop,
 			(gpointer)main_loop, FALSE, NULL);
-
-	g_cond_wait(atk_bridge_cond, atk_bridge_mutex);
-	g_mutex_unlock(atk_bridge_mutex);
 }
 
 typedef enum _SigalType {
